@@ -128,7 +128,7 @@ class Result(object):
             title=re.sub(r'\s+', ' ', title),
             authors=[Result.Author._from_feed_author(a) for a in entry.authors],
             summary=entry.summary,
-            comment=entry.get('comment'),
+            comment=entry.get('arxiv_comment'),
             journal_ref=entry.get('arxiv_journal_ref'),
             doi=entry.get('arxiv_doi'),
             primary_category=entry.arxiv_primary_category.get('term'),
@@ -170,10 +170,18 @@ class Result(object):
         """
         Returns the short ID for this result.
 
-        If the result URL is `"http://arxiv.org/abs/quant-ph/0201082v1"`,
-        `result.get_short_id()` returns `"0201082v1"`.
+        + If the result URL is `"http://arxiv.org/abs/2107.05580v1"`,
+        `result.get_short_id()` returns `2107.05580v1`.
+
+        + If the result URL is `"http://arxiv.org/abs/quant-ph/0201082v1"`,
+        `result.get_short_id()` returns `"quant-ph/0201082v1"` (the pre-March
+        2007 arXiv identifier format).
+
+        For an explanation of the difference between arXiv's legacy and current
+        identifiers, see [Understanding the arXiv
+        identifier](https://arxiv.org/help/arxiv_identifier).
         """
-        return self.entry_id.split('/')[-1]
+        return self.entry_id.split('arxiv.org/abs/')[-1]
 
     def _get_default_filename(self, extension: str = "pdf") -> str:
         """
@@ -627,7 +635,7 @@ class Client(object):
             feed = feedparser.parse(url)
             self._last_request_dt = datetime.now()
             if feed.status != 200:
-                err = HTTPError(url, retry, feed.status)
+                err = HTTPError(url, retry, feed)
             elif len(feed.entries) == 0 and not first_page:
                 err = UnexpectedEmptyPageError(url, retry)
             else:
@@ -655,7 +663,7 @@ class ArxivError(Exception):
         super().__init__(self.message)
 
     def __str__(self) -> str:
-        return '{}({})'.format(_classname(self), self.message)
+        return '{} ({})'.format(self.message, self.url)
 
 
 class UnexpectedEmptyPageError(ArxivError):
@@ -699,18 +707,29 @@ class HTTPError(ArxivError):
     """The request retry number which encountered this error, zero-indexed."""
     status: int
     """The HTTP status reported by feedparser."""
+    entry: feedparser.FeedParserDict
+    """The feed entry describing the error, if present."""
 
-    def __init__(self, url: str, retry: int, status: int):
+    def __init__(self, url: str, retry: int, feed: feedparser.FeedParserDict):
         """
         Constructs an `HTTPError` for the specified status code, encountered for
         the specified API URL after `retry` tries.
         """
         self.retry = retry
         self.url = url
-        self.status = status
+        self.status = feed.status
+        # If the feed is valid and includes a single entry, trust it's an
+        # explanation.
+        if not feed.bozo and len(feed.entries) == 1:
+            self.entry = feed.entries[0]
+        else:
+            self.entry = None
         super().__init__(
             url,
-            "Page request resulted in HTTP {}".format(self.status),
+            "Page request resulted in HTTP {}: {}".format(
+                self.status,
+                self.entry.summary if self.entry else None,
+            ),
         )
 
     def __repr__(self) -> str:
